// -----------------------------------------------------------------------------
// PARAMETERS:
// -----------------------------------------------------------------------------
//transforms
float4x4 tWVP: WORLDVIEWPROJECTION ;

//texture
texture Tex <string uiname="Texture";>;
sampler Samp = sampler_state    //sampler for doing the texture-lookup
{
    Texture   = (Tex);          //apply a texture to the sampler
    MipFilter = none;         //sampler states
    MinFilter = none;
    MagFilter = none;
};

bool Reset;
float Increment; //value to add every frame; passed from the patch

struct vs2ps
{
    float4 Pos : POSITION ;
    float4 TexCd : TEXCOORD0 ;
};

// -----------------------------------------------------------------------------
// VERTEXSHADERS
// -----------------------------------------------------------------------------
vs2ps VS(
    float4 Pos : POSITION ,
    float4 TexCd : TEXCOORD0 )
{
    vs2ps Out = (vs2ps)0;      //inititalize all fields of output struct with 0
    Out.Pos = mul(Pos, tWVP);  //transform position
    Out.TexCd = TexCd;

    return Out;
}

// -----------------------------------------------------------------------------
// PIXELSHADERS:
// -----------------------------------------------------------------------------
float4 PS(vs2ps In): COLOR
{
    //take the red from the last frame texture and add "Increment"
    float newRed = tex2D(Samp, In.TexCd).r + Increment; 
    // when reset the cycle:
    if(Reset) newRed = 0;
 
    return float4(newRed,0,0,0);
}

// -----------------------------------------------------------------------------
// TECHNIQUES:
// -----------------------------------------------------------------------------
technique CycleRed
{
    pass P0
    {
        VertexShader = compile vs_1_1 VS();
        PixelShader = compile ps_2_0 PS();
    }
}
